Module impact

Module impact 

Impact analysis: determine which parts of a module are affected by a patch.

Structs

Impact
The impact of a patch on a module: which functions and types are affected.

Functions

analyze_impact
Analyze the impact of a set of patch operations on a module.