invert_patch

Function invert_patch 

pub fn invert_patch(module: &Module, patch: &Patch) -> Result<Patch, PatchError>
Generate an inverse patch that undoes the given patch.

Must be called BEFORE the patch is applied, so we can capture the original state of modified nodes/functions.